.. -*- mode: rst -*-

|Travis|_

.. |Travis| image:: https://api.travis-ci.org/rlpy/rlpy.png?branch=master
.. _Travis: https://travis-ci.org/rlpy/rlpy

RLPy - Reinforment Learning Framework
======================================

RLPy is a framework to conduct sequential decision making experiments. The
current focus of this project lies on value-function-based reinforcement
learning. The project is distributed under the 3-Clause BSD License.

Important Links
===============

- Official source code repository: http://bitbucket.org/rlpy/rlpy
- Github Mirror: http://github.com/rlpy/rlpy
- Documentation and Homepage: http://acl.mit.edu/rlpy
- Issue Tracker: http://bitbucket.org/rlpy/rlpy/issues

Install
=======

Installation instructions can be found at http://acl.mit.edu/rlpy/install.html
